<?php
/**
 * eyesite functions and definitions
 *
 * @package eyesite
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 800; /* pixels */
}

if ( ! function_exists( 'eyesite_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function eyesite_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on eyesite, use a find and replace
	 * to change 'eyesite' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'eyesite', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
	
	add_theme_support ( 'woocommerce' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded title tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );


//add editor styles and link the google fonts to the editor styles (code to make the editor styled like the website)*********/
    add_editor_style( array( 'editor-style.css', eyesite_fonts_url() ) );


	/*
	 * Enable support for Post Thumbnails on posts and pages. thumbnails refers to images that can be any size - better called feature images
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 250);
	add_image_size ( 'eyesite-mid', 500 ); // can also include height and cropping option like this: ( 'mid', 500, 250, true );
	add_image_size( 'eyesite-feature', 800);//800 pixels wide and unlimited height if change these sizing names you also need to modify code in content.php files
	
	//adding in the new mid and default image sizes
	add_filter ( 'image_size_names_choose', 'my_custom_sizes' );
	
	function my_custom_sizes ( $sizes ) {
		return array_merge ( $sizes, array (
			'eyesite-feature' => __( 'eyesite-feature', 'eyesite' ),
			'eyesite-mid' => __( 'eyesite-mid', 'eyesite' ),
	) );
	}

	// This theme uses wp_nav_menu() in four locations.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'eyesite' ),
		'secondary' => __( 'Secondary menu in sidebar', 'eyesite'),//see sidebar.php
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );


	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'eyesite_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // eyesite_setup
add_action( 'after_setup_theme', 'eyesite_setup' );
	
/**
 * Register main widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function eyesite_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'eyesite' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
	/*register second and third widget areas*****/
	
	register_sidebar( array(
		'name'          => __( 'sidebar-footer', 'eyesite' ),
		'id'            => 'sidebar-footer',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
		register_sidebar( array(
		'name'          => __( 'sidebar-header', 'eyesite' ),
		'id'            => 'sidebar-header',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
}
add_action( 'widgets_init', 'eyesite_widgets_init' );


	
/**
 * Enqueue scripts and styles.
 */
function eyesite_scripts() {
	//main stylesheet
	wp_enqueue_style( 'eyesite-style', get_stylesheet_uri() );
	
	
	
	/* Enqueue the appropriate CSS based on which color scheme is selected via Theme Customizer */
	$eyesite_skin = get_theme_mod( 'eyesite_color_scheme' );
    if ( $eyesite_skin == 'white' ) {
		wp_enqueue_style( 'eyesite-white', get_template_directory_uri() .'/css/white.css' );
	} 
	else {
		wp_enqueue_style( 'eyesite-blue', get_template_directory_uri() .'/css/blue.css' );
	}
	
    wp_enqueue_style( 'eyesite-fonts', eyesite_fonts_url(), array(), null );

	wp_enqueue_script( 'eyesite-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'eyesite-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );
	
	//load script to make dropdown menus work with keyboard tabbing
	wp_enqueue_script( 'eyesite-accessible-dropdown-menu', get_template_directory_uri() . '/js/eyesite-accessible-dropdown-menu.js', array( 'jquery' ), true );



	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'eyesite_scripts' );


function eyesite_fonts_url() {
    $fonts_url = '';
 
    /* Translators: If there are characters in your language that are not
    * supported by Righteous, translate this to 'off'. Do not translate
    * into your own language.
    */
    $righteous = _x( 'on', 'Righteous font: on or off', 'eyesite' );

	
 //check if fonts have been deactivated by translators
    if ( 'off' !== $righteous ) {
        $font_families = array();
 
        if ( 'off' !== $righteous ) {
            $font_families[] = 'Righteous:400';
        }
 
 //generate the encoded fonts url
        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );
 
		$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
    }
 
    return $fonts_url;
}


/**
 * Set up the WordPress core custom header feature (used at the top of the content area on posts and front page in this theme).
 *
 */
function eyesite_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'eyesite_custom_header_args', array(
		'default-image'          => '',
		'default-text-color'     => 'ffffff',//heading (site-title and site-description) default colors
		'width'                  => 800,
		'height'                 => 250,
		'flex-height'            => true,//causes image to be cropped to specified height rather than scaled to fit
		'admin-preview-callback' => 'eyesite_admin_header_image',
	) ) );
}
add_action( 'after_setup_theme', 'eyesite_custom_header_setup' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';


/**alter excerpt length and read more link, can adjust the number below (currently 60 characters) if required*********/
function eyesite_excerpt_length( $length ) {
return 60;
}
add_filter( 'excerpt_length', 'eyesite_excerpt_length' );

function eyesite_excerpt_more( $more ) {
return '&hellip; <a href="'. get_permalink() . '">' . __( 'More &rarr;', 'eyesite' ) . '</a>';
}
add_filter( 'excerpt_more', 'eyesite_excerpt_more' );