<?php
/**
 * eyesite Theme Customizer
 *
 * @package eyesite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function eyesite_theme_customizer( $wp_customize ) {

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->remove_control ( 'display_header_text' ); //removes the checkbox 'display header text' that toggles the site title and tagline display
	


//LOGO
//add ability to upload LOGO using customizer
	$wp_customize->add_section( 'eyesite_logo_section' , array(
    'title'       => __( 'Logo', 'eyesite' ),
    'priority'    => 30, //priority no. just changes the list order of the options in the customiser interface
    'description' => __( 'Upload a logo to replace the default site name and description in the header. Recommended image height is between 100px and 200px', 'eyesite' ),
) );

$wp_customize->add_setting( 'eyesite_logo', array (
	'default' => '',
	'sanitize_callback' => 'esc_url_raw',
));

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'eyesite_logo', array(
    'label'    => __( 'Logo', 'eyesite' ),
    'section'  => 'eyesite_logo_section',
    'settings' => 'eyesite_logo',
	'default-image'          => '',
	'height'                 => 200,//size settings not operational
	'flex-height'            => false,
) ) );

//COLOR SCHEMES

	$wp_customize->add_setting( 'eyesite_color_scheme', array(
		'default'        => 'blue',
		'sanitize_callback' => 'eyesite_sanitize_color_scheme',
	) );

	$wp_customize->add_control( 'eyesite_color_scheme', array(
		'label'   => __( 'Choose your color scheme', 'eyesite' ),
		'section' => 'colors',
		'default'        => 'blue',
		'type'       => 'radio',
		'choices'    => array(
			'blue' => __( 'blue', 'eyesite' ),
			'white' => __( 'white', 'eyesite' ),
		),
	) );
	
	//sanitize color scheme choices
	function eyesite_sanitize_color_scheme ( $input ) {
		$valid = array (
			'blue' => 'blue',
			'white' => 'white',
		);
		
		if ( array_key_exists ( $input, $valid ) ) {
			return $input;
			} else {
				return '';
				}
	}
	


//FONTS
//add font customization options for main font (paragraphs and nav)
	$wp_customize->add_section( 'eyesite_fonts_section' , array(
    'title'       => __( 'Fonts', 'eyesite' ),
    'priority'    => 90,
    'description' => __( 'Select the fonts for your site', 'eyesite' ),
) );

$wp_customize->add_setting(
    'eyesite_font',
    array(
        'default'   => 'Helvetica',
		'sanitize_callback' => 'eyesite_sanitize_dropdown_font',
    )
);
//sanitize font options
function eyesite_sanitize_dropdown_font( $input ) {
    $valid = array(
            'Helvetica'  => 'Helvetica',
            'Arial'     => 'Arial',
            'Courier New'   => 'Courier New',
			'Georgia' => 'Georgia',
			'Tahoma' => 'Tahoma',
			'Verdana' => 'Verdana',
			'Times'  => 'Times New Roman',
    );

    if ( array_key_exists( $input, $valid ) ) {
       return $input;
    } else {
       return '';
    }
}

$wp_customize->add_control(
    'eyesite_font',
    array(
        'section'  => 'eyesite_fonts_section',
        'label'    => __( 'Main Font', 'eyesite' ),
        'type'     => 'select',
        'choices'  => array(
            'Helvetica'  =>  __( 'Helvetica', 'eyesite' ),
            'Arial'     => __( 'Arial', 'eyesite' ),
            'Courier New'   => __( 'Courier New', 'eyesite' ),
			'Georgia' => __( 'Georgia', 'eyesite' ),
			'Tahoma' => __( 'Tahoma', 'eyesite' ),
			'Verdana' => __( 'Verdana', 'eyesite' ),
			'Times'  => __( 'Times New Roman', 'eyesite' ),
        )
    )
);

//add font customization options for site title
$wp_customize->add_setting(
    'eyesite_heading_font',
    array(
        'default'   => 'Righteous',
		'section'    => 'fonts',
		'sanitize_callback' => 'eyesite_sanitize_dropdown',
    )
);

//sanitize heading font selection
function eyesite_sanitize_dropdown( $input ) {
    $valid = array(
			'Righteous' => 'Righteous',
			'Helvetica'  => 'Helvetica',
            'Arial'     => 'Arial',
            'Courier New'   => 'Courier New',
			'Georgia' => 'Georgia',
			'Tahoma' => 'Tahoma',
			'Verdana' => 'Verdana',
			'Times'  => 'Times New Roman',		
    );

    if ( array_key_exists( $input, $valid ) ) {
       return $input;
    } else {
       return '';
    }
}

$wp_customize->add_control(
    'eyesite_heading_font',
    array(
        'section'  => 'eyesite_fonts_section',
        'label'    => __( 'Headings Font', 'eyesite' ),
        'type'     => 'select',
        'choices'  => array(
			'Righteous' => __( 'Righteous', 'eyesite' ),
			'Helvetica'  =>  __( 'Helvetica', 'eyesite' ),
            'Arial'     => __( 'Arial', 'eyesite' ),
            'Courier New'   => __( 'Courier New', 'eyesite' ),
			'Georgia' => __( 'Georgia', 'eyesite' ),
			'Tahoma' => __( 'Tahoma', 'eyesite' ),
			'Verdana' => __( 'Verdana', 'eyesite' ),
			'Times'  => __( 'Times New Roman', 'eyesite' ),
        )
    )
);		

}
//various additions and subtractions to customizer all go above the final bracket above

add_action('customize_register', 'eyesite_theme_customizer');


//CSS CHANGES
//this bit enables the css changes when a change is made by the user in the customizer
//also adds links to the css sheets for each customizer color scheme selection
function eyesite_customizer_css() {
    ?>
    <style type="text/css">
		body { font-family: "<?php echo esc_attr( get_theme_mod( 'eyesite_font', 'Helvetica' ) ); ?>" }
		h1.site-title, h1.entry-title, .entry-content h2, .entry-content h4, .entry-content h6 { font-family: "<?php echo esc_attr( get_theme_mod( 'eyesite_heading_font', 'Righteous' ) ); ?>" }
    </style>
	
<?php
}
add_action( 'wp_head', 'eyesite_customizer_css' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function eyesite_customize_preview_js() {
	wp_enqueue_script( 'eyesite_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'eyesite_customize_preview_js' );